@@ -50,7 +50,7 @@ class BuzzAgent(object):
         for conf in self.alarm_config:
             stat_name = conf['stat_name']
 
-            stat_path = os.path.join(self.path, stat_name.replace('.', '/'))
+            stat_path = os.path.join(self.path, stat_name.replace('.', '/')) + '.wsp'
             logger.debug('stat_path: %s', stat_path)
 
             last_value = self.last_value_dict.get(stat_name, 0)
@@ -156,6 +156,8 @@ class BuzzAgent(object):
         """
         告警
         """
+        logger.error('config_id: %s, number_value: %s, slope_value: %s', config_id, number_value, slope_value)
+
         url = urlparse.urljoin('http://' + self.domain, ALARM_PATH)
 
         data = json.dumps(dict(
